@@ -171,6 +171,9 @@ class Graph:
 
         self.focus_nodes(focus_nodes.pop(), *focus_nodes)
 
+    def child_node_exists(self, node: ModuleNode) -> bool:
+        return self.master_graph.child_node_exists(node)
+
     def hide_node(self, node: ModuleNode):
         if node in self.nodes:
             self.nodes.remove(node)
@@ -203,6 +206,19 @@ class Graph:
             self.edges.remove(edge)
             self.edges.add(edge.with_style(style=edge_style))
 
+    def edge_style(
+        self, tail: ModuleNode, head: ModuleNode, color: Color, penwidth: PenWidth
+    ):
+        edge_style = ModuleEdgeStyle(color=color, penwidth=penwidth)
+        e = ModuleEdge(tail=tail, head=head)
+
+        edges = [
+            edge.with_style(edge_style) if edge.belongs_to(e) else edge
+            for edge in self.edges
+        ]
+        self.edges.clear()
+        self.edges.update(edges)
+
     def reset_style(self) -> None:
         nodes = [node.reset_style() for node in self.nodes]
         self.nodes.clear()
@@ -262,6 +278,10 @@ class Graph:
             # 既にクラスタ化されているので、処理をスキップする
             return
 
+        if not self.child_node_exists(node):
+            # dig できない (指定した node の配下に位置する node が存在しない)
+            raise ValueError(f"指定されたモジュール {node.name} の配下に位置するノードがありません (digできません)")
+
         node_owner = self.find_node_owner(node)
         if not node_owner:
             raise ValueError(f"指定されたモジュール {node.name} が存在しません。")
